@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20260114.1606
-;; Package-Revision: 4d7d58b75f6d
+;; Package-Version: 20260204.1727
+;; Package-Revision: 11a77f63a0cf
 ;; URL: https://github.com/jamescherti/persist-text-scale.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "26.1"))
@@ -274,8 +274,8 @@ If the buffer category is nil or no scale amount has been stored, return nil."
   (when category
     (let ((cat-data (or (cdr (assoc category persist-text-scale--data))
                         ;; TODO store this per category intead
-                        (when persist-text-scale-fallback-to-previous-scale
-                          persist-text-scale--last-text-scale-amount)
+                        ;; (when persist-text-scale-fallback-to-previous-scale
+                        ;;   persist-text-scale--last-text-scale-amount)
                         (when (integerp
                                persist-text-scale-default-text-scale-amount)
                           persist-text-scale-default-text-scale-amount))))
@@ -335,14 +335,6 @@ OBJECT can be a frame or a window."
           (with-selected-window window
             (when-let* ((buffer (window-buffer)))
               (with-current-buffer buffer
-                (when (and (buffer-base-buffer)
-                           (not persist-text-scale--indirect-buffer-initialized))
-                  (when (bound-and-true-p text-scale-mode-amount)
-                    (setq persist-text-scale--restored-amount text-scale-mode-amount)
-                    (setq persist-text-scale--persisted-amount nil)
-                    (persist-text-scale-persist))
-                  (setq persist-text-scale--indirect-buffer-initialized t))
-
                 ;; Restore all windows
                 (persist-text-scale--restore-all-windows)))))))))
 
@@ -554,7 +546,7 @@ This function writes the text scale data to the file specified by
 
 ;;;###autoload
 (define-minor-mode persist-text-scale-mode
-  "Toggle `persist-text-scale-mode'."
+  "Persist and restore text scale."
   :global t
   :lighter " PTScale"
   :group 'persist-text-scale
